==> gbook-0.5.tar.bz2: gbook/gbook.i18n-fr.php <==
<?

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2006 Tino Reichardt
 * Copyright (C) 2006 Paul Denuit
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "Nom",
'f_origin'        => "Origine",
'f_ip'            => "Ip",
'f_browser'       => "Navigateur",
'f_email'         => "Email",
'f_homepage'      => "Site web",
'f_captcha'       => "captcha",
'f_entry'         => "Votre billet",
'f_ip'            => "Ip",
'f_browser'       => "Navigateur",

# buttons
'b_submit'        => "Soumettre",
'b_change'        => "Editer",
'b_delete'        => "Supprimer",
'b_reset'         => "Reset",

# misc
'headline'        => "Livre d'or",
'hl_create'       => "D&eacute;poser un nouveau billet :",
'hl_modify'       => "Modifier un billet:",
'new_entry'       => "Bienvenue sur le livre d'or. Vous pouvez ajouter un nouveau billet [[Special:Guestbook&action=add|'''ici''']].",
'entry_okay'      => "Votre billet a &eacute;t&eacute; ajout&eacute; au livre d'or. Merci ;)",
'delete_okay'     => "Le billet n'existe plus.",
'change_okay'     => "Le billet a bien &eacute;t&eacute; modifi&eacute;.",
'show_entries'    => "Voir les autres billets.",
'captcha_desc'    => "Recopiez les lettres et les nombres de la petite image ci-dessous.",
'captcha_fail'    => "D&eacute;sol&eacute;, le captcha n'est pas correct!",
'err_name'        => "D&eacute;sol&eacute;, votre nom est demand&eacute;!",
'err_entry'       => "D&eacute;sol&eacute;, votre billet semble vide!",
'err_noentry'     => "D&eacute;sol&eacute;, ce billet n'existe pas ou plus!",
'err_captcha'     => "D&eacute;sol&eacute;, le captcha est vide!"
);

?>

==> gbook-0.6.tar.bz2: gbook/gbook.i18n-fr.php <==
<?

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2006 Tino Reichardt
 * Copyright (C) 2006 Paul Denuit
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "Nom",
'f_origin'        => "Origine",
'f_ip'            => "Ip",
'f_browser'       => "Navigateur",
'f_email'         => "Email",
'f_homepage'      => "Site web",
'f_captcha'       => "captcha",
'f_entry'         => "Votre billet",
'f_ip'            => "Ip",
'f_browser'       => "Navigateur",

# buttons
'b_submit'        => "Soumettre",
'b_change'        => "Editer",
'b_delete'        => "Supprimer",
'b_reset'         => "Reset",

# misc
'headline'        => "Livre d'or",
'hl_create'       => "D&eacute;poser un nouveau billet :",
'hl_modify'       => "Modifier un billet:",
'new_entry'       => "Bienvenue sur le livre d'or. Vous pouvez ajouter un nouveau billet [{{fullurl:Special:Guestbook|action=add}} '''ici'''].",
'entry_okay'      => "Votre billet a &eacute;t&eacute; ajout&eacute; au livre d'or. Merci ;)",
'delete_okay'     => "Le billet n'existe plus.",
'change_okay'     => "Le billet a bien &eacute;t&eacute; modifi&eacute;.",
'show_entries'    => "Voir les autres billets.",
'captcha_desc'    => "Recopiez les lettres et les nombres de la petite image ci-dessous.",
'captcha_fail'    => "D&eacute;sol&eacute;, le captcha n'est pas correct!",
'err_name'        => "D&eacute;sol&eacute;, votre nom est demand&eacute;!",
'err_entry'       => "D&eacute;sol&eacute;, votre billet semble vide!",
'err_noentry'     => "D&eacute;sol&eacute;, ce billet n'existe pas ou plus!",
'err_captcha'     => "D&eacute;sol&eacute;, le captcha est vide!"
);

?>
